pub struct EndIslands {
island_noise: SimplexNoise,
}Expand description
End islands density function.
Unlike overworld/nether density functions which are transpiled into native Rust, this is used directly at runtime because it’s a self-contained leaf algorithm (simplex noise + neighbor loop) with no density function tree to transpile.
Fields
island_noise: SimplexNoiseImplementations
Sourceimpl EndIslands
impl EndIslands
Sourcepub fn new(seed: u64) -> EndIslands
pub fn new(seed: u64) -> EndIslands
Create a new EndIslands with the given world seed.
Matches vanilla’s RandomState.NoiseWiringHelper.wrapNew() which creates
EndIslandDensityFunction(worldSeed), NOT seed 0. The JSON codec defaults
to seed 0, but RandomState replaces it with the world seed.